# Multiplication-Table-in-Python-3
To create multiplication table of any integer using Python Program

Initially, the number whose multiplication table is to be displayed is received as input. Then a list of multiples(up to 10) of the number is created. Afterward, a counter is added to the iterable using enumerate() method; which in turn returns as enumerate object. Finally, the multiplication table is printed.
